diff -pruN 1.57/debian/cdrom-detect.postinst 1.57ubuntu9/debian/cdrom-detect.postinst
--- 1.57/debian/cdrom-detect.postinst	2015-05-13 03:00:48.000000000 +0000
+++ 1.57ubuntu9/debian/cdrom-detect.postinst	2015-10-27 13:59:30.000000000 +0000
@@ -28,7 +28,7 @@ try_mount() {
 			db_set cdrom-detect/cdrom_fs $type
 			ret=0
 		else
-			log "The CD in $device is not a Debian CD!"
+			log "The CD in $device is not an Ubuntu CD!"
 			umount /cdrom 2>/dev/null || true
 			WRONG=1
 		fi
@@ -85,20 +85,24 @@ mount | grep -q 'on /cdrom' && set_suite
 if [ -e /cdrom/.disk/info ]; then
 	CDNAME=$(cat /cdrom/.disk/info)
 	log "Detected CD '$CDNAME'"
+	# This produces /var/log/installer/media-info on the installed
+	# system.
+	printf %s "$CDNAME" >/var/log/media-info
 	set_suite_and_codename
 	exit 0
 fi
 
 hw-detect cdrom-detect/detect_progress_title || true
 
-log "Searching for Debian installation media..."
+log "Searching for Ubuntu installation media..."
 
 mkdir /cdrom 2>/dev/null || true
 
 # Need to wait for the usb device scan to complete
 if [ "$OS" = "linux" ]; then
   for count in 1 2 3 4 5 6 8 9 10; do
-    devices="$(list-devices cd; list-devices maybe-usb-floppy)"
+    devices="$(list-devices cd; list-devices maybe-usb-floppy;
+	       list-devices usb-partition; list-devices mmc-partition)"
     log "Devices: '$devices'"
     if [ -n "$devices" ]; then
       break 2
@@ -119,6 +123,7 @@ while true; do
 	done
 	
 	devices="$(list-devices usb-partition)"
+	devices="$devices $(list-devices mmc-partition)"
 	for device in $devices; do
 		if try_mount $device $CDFS; then
 			db_set cdrom-detect/hybrid true
@@ -223,6 +228,22 @@ while true; do
 	fi
 done
 
+db_get cdrom-detect/cdrom_device
+device="$RET"
+
+ARCH="`udpkg --print-architecture`"
+if [ "$ARCH" = i386 ]; then
+	db_input low cdrom-detect/cdrom_hdparm || [ $? -eq 30 ]
+	db_go
+	db_get cdrom-detect/cdrom_hdparm
+	params="`printf '%s' "$RET" | sed 's/^ *//'`"
+
+	if [ "$device" ] && [ "$params" ]; then
+		hdparm $params "$device"
+		apt-install hdparm || true
+	fi
+fi
+
 # Check for unetbootin files
 UNETBOOTIN_FILES="ubnfilel.txt ubninit ubnkern ubnpathl.txt"
 UNETBOOTIN_DETECTED=0
@@ -265,6 +286,9 @@ fi
 # Install eject-udeb, to be able to use it in the finish-install script.
 anna-install eject-udeb || true
 
+# This produces /var/log/installer/media-info on the installed system.
+printf %s "$CDNAME" >/var/log/media-info
+
 # Hey, we're done
 db_subst cdrom-detect/success cdname "$CDNAME"
 db_input low cdrom-detect/success || [ $? -eq 30 ]
diff -pruN 1.57/debian/cdrom-detect.templates 1.57ubuntu9/debian/cdrom-detect.templates
--- 1.57/debian/cdrom-detect.templates	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/cdrom-detect.templates	2019-10-30 16:14:47.000000000 +0000
@@ -134,9 +134,10 @@ Description: for internal use; can be pr
 
 Template: cdrom/suite
 Type: select
-Choices: stable, testing, unstable
+Choices: xenial, bionic, disco, eoan, focal
+Default: focal
 Description: for internal use only
- Debian version to install
+ Ubuntu version to install
 
 Template: cdrom/codename
 Type: string
@@ -154,3 +155,10 @@ Type: text
 #  Item in the main menu to select this package
 # :sl2:
 _Description: Detect and mount CD-ROM
+
+Template: cdrom-detect/cdrom_hdparm
+Type: string
+_Description: Tune CD-ROM drive parameters with hdparm?
+ The installer can use hdparm to tune some CD-ROM drive parameters, which
+ may significantly speed up reading packages from the CD. You can change the
+ parameters to be used. To disable hdparm, enter an empty parameter list.
diff -pruN 1.57/debian/changelog 1.57ubuntu9/debian/changelog
--- 1.57/debian/changelog	2015-10-02 05:00:31.000000000 +0000
+++ 1.57ubuntu9/debian/changelog	2019-10-30 16:14:49.000000000 +0000
@@ -1,3 +1,66 @@
+cdrom-detect (1.57ubuntu9) focal; urgency=medium
+
+  * Set cdrom/suite default to focal and drop cosmic.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Wed, 30 Oct 2019 10:14:49 -0600
+
+cdrom-detect (1.57ubuntu8) eoan; urgency=medium
+
+  * Set cdrom/suite default to eoan and drop trusty.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Sun, 21 Apr 2019 23:35:50 -0600
+
+cdrom-detect (1.57ubuntu7) disco; urgency=medium
+
+  * Set cdrom/suite default to disco and drop artful.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Wed, 31 Oct 2018 22:51:17 -0600
+
+cdrom-detect (1.57ubuntu6) cosmic; urgency=medium
+
+  * Set cdrom/suite default to cosmic and drop zesty.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Wed, 02 May 2018 14:50:43 -0600
+
+cdrom-detect (1.57ubuntu5) bionic; urgency=medium
+
+  * Set cdrom/suite default to bionic and drop yakkety.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Tue, 07 Nov 2017 15:13:02 -0700
+
+cdrom-detect (1.57ubuntu4) artful; urgency=medium
+
+  * Set cdrom/suite default to artful and drop precise.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Wed, 26 Apr 2017 11:59:37 -0600
+
+cdrom-detect (1.57ubuntu3) zesty; urgency=medium
+
+  * Set cdrom/suite default to zesty and drop wily.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Mon, 24 Oct 2016 12:15:19 -0600
+
+cdrom-detect (1.57ubuntu2) yakkety; urgency=medium
+
+  * Set cdrom/suite default to yakkety and drop vivid.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Fri, 22 Apr 2016 05:57:51 -0600
+
+cdrom-detect (1.57ubuntu1) xenial; urgency=medium
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+  * Set cdrom/suite default to xenial and drop utopic.
+
+ -- Mathieu Trudel-Lapierre <mathieu-tl@ubuntu.com>  Tue, 27 Oct 2015 10:10:05 -0400
+
 cdrom-detect (1.57) unstable; urgency=medium
 
   [ Updated translations ]
@@ -86,6 +149,33 @@ cdrom-detect (1.48) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Tue, 09 Sep 2014 11:05:35 +0200
 
+cdrom-detect (1.47ubuntu3) wily; urgency=medium
+
+  * Set cdrom/suite default to wily and drop lucid.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Tue, 05 May 2015 01:22:24 -0600
+
+cdrom-detect (1.47ubuntu2) vivid; urgency=medium
+
+  * Set cdrom/suite default to vivid and drop saucy.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Wed, 29 Oct 2014 23:33:01 -0600
+
+cdrom-detect (1.47ubuntu1) utopic; urgency=medium
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+  * Set cdrom/suite default to utopic; drop quantal and raring.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Thu, 26 Jun 2014 13:29:13 +0100
+
 cdrom-detect (1.47) unstable; urgency=low
 
   [ Updated translations ]
@@ -95,6 +185,21 @@ cdrom-detect (1.47) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Fri, 13 Jun 2014 07:11:26 +0200
 
+cdrom-detect (1.46ubuntu1) trusty; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+  * Set cdrom/suite default to trusty; drop hardy.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 23 Oct 2013 11:35:09 +0100
+
 cdrom-detect (1.46) unstable; urgency=low
 
   [ Updated translations ]
@@ -111,6 +216,20 @@ cdrom-detect (1.45) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Sat, 13 Jul 2013 13:45:09 +0200
 
+cdrom-detect (1.44ubuntu1) saucy; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Thu, 06 Jun 2013 17:29:00 +0100
+
 cdrom-detect (1.44) unstable; urgency=low
 
   [ Updated translations ]
@@ -118,6 +237,26 @@ cdrom-detect (1.44) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Wed, 15 May 2013 14:42:37 +0200
 
+cdrom-detect (1.43ubuntu2) saucy; urgency=low
+
+  * Set cdrom/suite default to saucy; drop oneiric.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue, 30 Apr 2013 00:16:02 +0100
+
+cdrom-detect (1.43ubuntu1) raring; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 11 Jan 2013 11:39:30 +0000
+
 cdrom-detect (1.43) unstable; urgency=low
 
   [ Updated translations ]
@@ -127,6 +266,21 @@ cdrom-detect (1.43) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Sun, 09 Dec 2012 17:05:10 +0100
 
+cdrom-detect (1.42ubuntu1) raring; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+  * Set cdrom/suite default to raring; drop natty.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 07 Nov 2012 12:53:57 +0000
+
 cdrom-detect (1.42) unstable; urgency=low
 
   * Replace XC-Package-Type by Package-Type in debian/control
@@ -137,6 +291,20 @@ cdrom-detect (1.42) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Sun, 14 Oct 2012 10:19:57 +0200
 
+cdrom-detect (1.41ubuntu1) quantal; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 10 Aug 2012 15:46:00 +0100
+
 cdrom-detect (1.41) unstable; urgency=low
 
   * Team upload
@@ -154,6 +322,21 @@ cdrom-detect (1.41) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Fri, 15 Jun 2012 06:51:53 +0200
 
+cdrom-detect (1.40ubuntu1) quantal; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+  * Set cdrom/suite default to quantal; drop maverick.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 02 May 2012 12:22:28 +0100
+
 cdrom-detect (1.40) unstable; urgency=low
 
   [ Updated translations ]
@@ -179,6 +362,33 @@ cdrom-detect (1.40) unstable; urgency=lo
 
  -- Otavio Salvador <otavio@debian.org>  Thu, 15 Mar 2012 14:34:11 -0300
 
+cdrom-detect (1.39ubuntu3) precise; urgency=low
+
+  * Update Ubuntu-specific translations from Launchpad.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 11 Apr 2012 11:31:05 +0100
+
+cdrom-detect (1.39ubuntu2) precise; urgency=low
+
+  * Set cdrom/suite default to precise; drop dapper.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue, 18 Oct 2011 23:39:45 +0100
+
+cdrom-detect (1.39ubuntu1) oneiric; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+  * Set cdrom/suite default to oneiric; drop karmic.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue, 03 May 2011 14:22:22 +0100
+
 cdrom-detect (1.39) unstable; urgency=low
 
   [ Christian Perrier ]
@@ -211,6 +421,20 @@ cdrom-detect (1.39) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Sat, 23 Apr 2011 12:09:16 +0200
 
+cdrom-detect (1.38ubuntu1) natty; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 26 Jan 2011 14:19:01 +0000
+
 cdrom-detect (1.38) unstable; urgency=low
 
   * Set cdrom-detect/usb-hdd when the "CD" is really a live USB-HDD
@@ -235,6 +459,20 @@ cdrom-detect (1.37) unstable; urgency=lo
 
  -- Otavio Salvador <otavio@debian.org>  Fri, 24 Dec 2010 19:35:47 -0200
 
+cdrom-detect (1.36ubuntu1) natty; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - Extend device-scan delay to wait for usb-partition and mmc-partition
+      as well.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Mon, 15 Nov 2010 10:24:32 +0000
+
 cdrom-detect (1.36) unstable; urgency=low
 
   [ Christian Perrier ]
@@ -248,6 +486,25 @@ cdrom-detect (1.36) unstable; urgency=lo
 
  -- Otavio Salvador <otavio@debian.org>  Fri, 12 Nov 2010 10:00:46 -0200
 
+cdrom-detect (1.35ubuntu1) natty; urgency=low
+
+  * Resynchronise with Debian.  Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Also check SD/MMC partitions ("list-devices mmc-partition").
+    - Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+      /var/log/installer/media-info on the installed system.
+    - usb-storage sometimes seems to take a while to settle to the point of
+      actually exposing block devices, despite the 'udevadm settle' in
+      hw-detect.  I don't see an easy way to solve this, so, with
+      reservations, retry the detection loop three times with a 'sleep 3' in
+      between in the event that no devices are found, in the hope that that
+      improves matters.
+  * Set cdrom/suite default to natty; drop jaunty.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Thu, 21 Oct 2010 21:55:32 +0100
+
 cdrom-detect (1.35) unstable; urgency=low
 
   * Team upload.
@@ -322,6 +579,52 @@ cdrom-detect (1.33) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Sat, 10 Jul 2010 21:44:25 +0200
 
+cdrom-detect (1.32ubuntu5) maverick; urgency=low
+
+  * usb-storage sometimes seems to take a while to settle to the point of
+    actually exposing block devices, despite the 'udevadm settle' in
+    hw-detect.  I don't see an easy way to solve this, so, with
+    reservations, retry the detection loop three times with a 'sleep 3' in
+    between in the event that no devices are found, in the hope that that
+    improves matters (LP: #586036).
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 04 Jun 2010 18:23:26 +0100
+
+cdrom-detect (1.32ubuntu4) maverick; urgency=low
+
+  * Set cdrom/suite default to maverick; drop intrepid.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue, 25 May 2010 18:48:38 +0100
+
+cdrom-detect (1.32ubuntu3) lucid; urgency=low
+
+  * Update Ubuntu-specific translations from Launchpad.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Thu, 15 Apr 2010 00:02:20 +0100
+
+cdrom-detect (1.32ubuntu2) lucid; urgency=low
+
+  * Copy /cdrom/.disk/info to /var/log/media-info, in order that we get
+    /var/log/installer/media-info on the installed system; doing this in
+    save-logs is too late because /cdrom is already unmounted by that point
+    (LP: #364649).
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 04 Dec 2009 17:27:09 +0000
+
+cdrom-detect (1.32ubuntu1) lucid; urgency=low
+
+  * Merge from Debian testing, remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Update translations from Launchpad.
+    - Also check SD/MMC partitions ("list-devices mmc-partition") when
+      cdrom-detect/try-usb is set; update template description to reflect
+      this
+  * Set cdrom/suite default to lucid.
+
+ -- Steve Langasek <steve.langasek@ubuntu.com>  Tue, 10 Nov 2009 11:40:51 +0000
+
 cdrom-detect (1.32) unstable; urgency=low
 
   [ Colin Watson ]
@@ -351,6 +654,32 @@ cdrom-detect (1.32) unstable; urgency=lo
 
  -- Otavio Salvador <otavio@debian.org>  Sun, 08 Nov 2009 13:23:10 -0200
 
+cdrom-detect (1.31ubuntu3) karmic; urgency=low
+
+  * Also check SD/MMC partitions ("list-devices mmc-partition") when
+    cdrom-detect/try-usb is set; update template description to reflect this;
+    bump di-utils udeb dep to >= 1.67ubuntu1 for this list-devices feature;
+    LP: #364604.
+
+ -- Loïc Minier <loic.minier@ubuntu.com>  Tue, 06 Oct 2009 23:05:19 +0100
+
+cdrom-detect (1.31ubuntu2) karmic; urgency=low
+
+  * Update translations from Launchpad.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue, 01 Sep 2009 13:12:11 +0100
+
+cdrom-detect (1.31ubuntu1) karmic; urgency=low
+
+  * Resynchronise with Debian. Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+    - Record the filesystem used to mount cdrom-detect/cdrom_device in
+      cdrom-detect/cdrom_fs for later use.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 24 Jun 2009 17:33:56 +0100
+
 cdrom-detect (1.31) unstable; urgency=low
 
   [ Updated translations ]
@@ -376,6 +705,38 @@ cdrom-detect (1.31) unstable; urgency=lo
 
  -- Christian Perrier <bubulle@debian.org>  Sun, 14 Jun 2009 16:36:27 +0200
 
+cdrom-detect (1.30ubuntu4) karmic; urgency=low
+
+  * Merge unreleased translations from Debian svn
+  * Set cdrom/suite default to karmic.
+  * Drop gutsy from cdrom/suite Choices, since it's now unsupported.
+
+ -- Steve Langasek <steve.langasek@ubuntu.com>  Mon, 04 May 2009 05:11:54 -0700
+
+cdrom-detect (1.30ubuntu3) jaunty; urgency=low
+
+  * Update Ubuntu-specific strings from Launchpad.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Thu, 09 Apr 2009 02:04:57 +0100
+
+cdrom-detect (1.30ubuntu2) jaunty; urgency=low
+
+  * Record the filesystem used to mount cdrom-detect/cdrom_device in
+    cdrom-detect/cdrom_fs for later use.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 14 Jan 2009 15:02:13 +0000
+
+cdrom-detect (1.30ubuntu1) jaunty; urgency=low
+
+  * Resynchronise with Debian. Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+  * Set cdrom/suite default to jaunty.
+  * Drop feisty from cdrom/suite Choices, since it's now unsupported.
+
+ -- Steve Langasek <steve.langasek@ubuntu.com>  Fri, 07 Nov 2008 16:41:44 -0800
+
 cdrom-detect (1.30) unstable; urgency=low
 
   [ Updated translations ]
@@ -452,6 +813,40 @@ cdrom-detect (1.29) unstable; urgency=lo
 
  -- Joey Hess <joeyh@debian.org>  Mon, 07 Jul 2008 14:07:50 -0400
 
+cdrom-detect (1.28ubuntu4) intrepid; urgency=low
+
+  * Try to find an Ubuntu image on every CD device, not just the first
+    (LP: #234185).
+
+ -- Evan Dandrea <evand@ubuntu.com>  Sun, 19 Oct 2008 17:29:04 -0400
+
+cdrom-detect (1.28ubuntu3) intrepid; urgency=low
+
+  * Update Ubuntu-specific strings from Launchpad.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Sun, 12 Oct 2008 00:02:33 +0100
+
+cdrom-detect (1.28ubuntu2) intrepid; urgency=low
+
+  * allow installation from USB media with CD contents
+    - enabled if template cdrom-detect/try-usb=true
+    - probe vfat partitions on USB drives
+  * bump dependency on d-i-utils to 1.59ubuntu3 for above change
+
+ -- Tormod Volden <debian.tormod@gmail.com>  Sat, 27 Sep 2008 12:18:48 +0200
+
+cdrom-detect (1.28ubuntu1) intrepid; urgency=low
+
+  [ Colin Watson ]
+  * Resynchronise with Debian. Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+  * Set cdrom/suite default to intrepid.
+  * Drop edgy from cdrom/suite Choices, since it's now unsupported.
+
+ -- Steve Langasek <steve.langasek@ubuntu.com>  Wed, 11 Jun 2008 12:40:44 -0700
+
 cdrom-detect (1.28) unstable; urgency=low
 
   [ Frans Pop ]
@@ -501,6 +896,23 @@ cdrom-detect (1.26) unstable; urgency=lo
 
  -- Frans Pop <fjp@debian.org>  Wed, 06 Feb 2008 17:25:10 +0100
 
+cdrom-detect (1.25ubuntu2) hardy; urgency=low
+
+  * Set Vcs-Bzr for Ubuntu.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 29 Feb 2008 18:55:02 +0000
+
+cdrom-detect (1.25ubuntu1) hardy; urgency=low
+
+  * Resynchronise with Debian. Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+  * Set cdrom/suite default to hardy.
+  * Drop unsupported releases from cdrom/suite Choices.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Sat, 20 Oct 2007 03:18:36 +0100
+
 cdrom-detect (1.25) unstable; urgency=low
 
   [ Joey Hess ]
@@ -548,6 +960,15 @@ cdrom-detect (1.23) unstable; urgency=lo
 
  -- Frans Pop <fjp@debian.org>  Fri, 06 Jul 2007 00:11:06 +0200
 
+cdrom-detect (1.22ubuntu1) gutsy; urgency=low
+
+  * Resynchronise with Debian. Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 11 May 2007 16:55:27 +0200
+
 cdrom-detect (1.22) unstable; urgency=low
 
   [ Joey Hess ]
@@ -558,6 +979,16 @@ cdrom-detect (1.22) unstable; urgency=lo
 
  -- Frans Pop <fjp@debian.org>  Thu, 26 Apr 2007 08:08:52 +0200
 
+cdrom-detect (1.21ubuntu1) gutsy; urgency=low
+
+  * Resynchronise with Debian. Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+  * Set cdrom/suite default to gutsy.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 25 Apr 2007 21:56:30 +0100
+
 cdrom-detect (1.21) unstable; urgency=low
 
   * Multiply menu-item-numbers by 100
@@ -602,6 +1033,22 @@ cdrom-detect (1.19) unstable; urgency=lo
 
  -- Frans Pop <fjp@debian.org>  Wed, 31 Jan 2007 11:28:14 +0100
 
+cdrom-detect (1.18ubuntu2) feisty; urgency=low
+
+  * Set Maintainer to ubuntu-installer@lists.ubuntu.com.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 16 Feb 2007 10:06:41 +0000
+
+cdrom-detect (1.18ubuntu1) feisty; urgency=low
+
+  * Resynchronise with Debian. Remaining changes:
+    - Ubuntu branding (including cdrom/suite Choices and Default).
+    - Allow setting default CD-ROM drive parameters using
+      cdrom-detect/cdrom_hdparm.
+  * Set cdrom/suite default to feisty.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue, 31 Oct 2006 11:16:33 +0000
+
 cdrom-detect (1.18) unstable; urgency=low
 
   * Simplify CD-ROM detection (remove automatic retry as code already allows
@@ -654,6 +1101,24 @@ cdrom-detect (1.17) unstable; urgency=lo
 
  -- Colin Watson <cjwatson@debian.org>  Thu, 31 Aug 2006 17:29:01 +0100
 
+cdrom-detect (1.16ubuntu2) edgy; urgency=low
+
+  * Backport from trunk:
+    - Use list-devices to look for CD devices. Requires di-utils 1.33.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri,  1 Sep 2006 16:07:35 +0100
+
+cdrom-detect (1.16ubuntu1) edgy; urgency=low
+
+  * Resynchronise with Debian.
+  * Set cdrom/suite default to edgy.
+  * Update Ubuntu-specific strings from Rosetta: Bulgarian, Catalan, Czech,
+    Greek, Esperanto, Basque, Finnish, Hebrew, Croatian, Hungarian,
+    Indonesian, Icelandic, Italian, Lithuanian, Latvian, Russian, Slovenian,
+    Thai, Tagalog, Turkish, Ukrainian, Simplified Chinese.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 30 Jun 2006 18:30:10 +0100
+
 cdrom-detect (1.16) unstable; urgency=low
 
   * Change menu item number from 14 to 13. cdrom-detect, load-iso,
@@ -768,6 +1233,13 @@ cdrom-detect (1.13) unstable; urgency=lo
 
  -- Frans Pop <fjp@debian.org>  Wed, 19 Apr 2006 19:40:12 +0200
 
+cdrom-detect (1.12ubuntu1) dapper; urgency=low
+
+  * Resynchronise with Debian.
+  * Update Portuguese translation from Rosetta.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Mon, 20 Mar 2006 18:17:34 +0000
+
 cdrom-detect (1.12) unstable; urgency=low
 
   [ Updated translations ]
@@ -795,6 +1267,12 @@ cdrom-detect (1.12) unstable; urgency=lo
 
  -- Frans Pop <fjp@debian.org>  Mon, 23 Jan 2006 20:21:37 +0100
 
+cdrom-detect (1.11ubuntu1) dapper; urgency=low
+
+  * Resynchronise with Debian.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Sat, 26 Nov 2005 11:01:54 +0000
+
 cdrom-detect (1.11) unstable; urgency=low
 
   * Also determine the codename of the release. This can be used later to
@@ -802,6 +1280,13 @@ cdrom-detect (1.11) unstable; urgency=lo
 
  -- Frans Pop <fjp@debian.org>  Tue, 15 Nov 2005 20:30:19 +0100
 
+cdrom-detect (1.10ubuntu1) dapper; urgency=low
+
+  * Resynchronise with Debian.
+  * Update mirror/suite for dapper.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Mon, 31 Oct 2005 10:06:35 -0500
+
 cdrom-detect (1.10) unstable; urgency=low
 
   [ Colin Watson ]
@@ -881,6 +1366,28 @@ cdrom-detect (1.08) unstable; urgency=lo
 
  -- Joey Hess <joeyh@debian.org>  Mon, 13 Jun 2005 12:31:52 -0400
 
+cdrom-detect (1.07ubuntu3) breezy; urgency=low
+
+  * Update fuzzy and missing translations from Rosetta (with some strings
+    from Debian where available): Danish, Spanish, Hungarian, Norwegian
+    Bokmål, Dutch, Polish, Portuguese, Slovak, Swedish.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Sun,  2 Oct 2005 15:20:33 +0100
+
+cdrom-detect (1.07ubuntu2) breezy; urgency=low
+
+  * We only really support installing the default suite, so mark
+    mirror/suite untranslatable. This removes two strings that are awkward
+    for derivatives to brand.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Wed, 20 Jul 2005 19:38:58 +0100
+
+cdrom-detect (1.07ubuntu1) breezy; urgency=low
+
+  * Resynchronise with Debian.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Mon, 20 Jun 2005 18:29:48 +0100
+
 cdrom-detect (1.07) unstable; urgency=low
 
   * Joey Hess
@@ -908,6 +1415,12 @@ cdrom-detect (1.07) unstable; urgency=lo
 
  -- Joey Hess <joeyh@debian.org>  Sat, 11 Jun 2005 13:31:25 -0400
 
+cdrom-detect (1.06ubuntu1) breezy; urgency=low
+
+  * Resynchronise with Debian.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Mon,  9 May 2005 13:59:04 +0100
+
 cdrom-detect (1.06) unstable; urgency=low
 
   * Stephen R. Marenka
@@ -954,6 +1467,13 @@ cdrom-detect (1.06) unstable; urgency=lo
 
  -- Joey Hess <joeyh@debian.org>  Sun,  1 May 2005 17:18:41 -0400
 
+cdrom-detect (1.05ubuntu1) breezy; urgency=low
+
+  * Resynchronise with Debian.
+  * Sync mirror/suite description with other udebs.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Fri, 15 Apr 2005 10:26:06 +0100
+
 cdrom-detect (1.05) unstable; urgency=low
 
   * Note that this includes variable substitution fixes for translated
@@ -979,6 +1499,74 @@ cdrom-detect (1.05) unstable; urgency=lo
 
  -- Joey Hess <joeyh@debian.org>  Wed,  2 Feb 2005 17:07:46 -0500
 
+cdrom-detect (1.04ubuntu9) hoary; urgency=low
+
+  * Update Norwegian Bokmål translation (thanks, Terance Edward Sola).
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue,  5 Apr 2005 16:58:26 +0100
+
+cdrom-detect (1.04ubuntu8) hoary; urgency=low
+
+  * Update Greek translation (thanks, Giorgos Logiotatidis).
+  * Update Romanian translation (thanks, Ovidiu Damian).
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue,  5 Apr 2005 16:24:15 +0100
+
+cdrom-detect (1.04ubuntu7) hoary; urgency=low
+
+  * Update Indonesian translation (thanks, Yoppy Hidayanto).
+  * Update Hungarian translation (thanks, Gabor Burjan).
+  * Update Brazilian Portuguese translation (thanks, Carlos Eduardo Pedroza
+    Santiviago).
+  * Update Polish translation (thanks, Dominik Zabłotny).
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Mon, 28 Mar 2005 20:10:16 +0100
+
+cdrom-detect (1.04ubuntu6) hoary; urgency=low
+
+  * Update Brazilian Portuguese translation (thanks, Carlos Eduardo Pedroza
+    Santiviago).
+  * Update French translation (thanks, Sebastien Bacher).
+  * Update German translation (thanks, Herbert Straub).
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Sat, 26 Mar 2005 00:43:32 +0000
+
+cdrom-detect (1.04ubuntu5) hoary; urgency=low
+
+  * Add draft Xhosa translation.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Tue, 22 Mar 2005 14:38:04 +0000
+
+cdrom-detect (1.04ubuntu4) hoary; urgency=low
+
+  * Revert change in 1.04ubuntu2, thus moving prebaseconfig script back
+    before final-message. On a number of systems, having it afterwards means
+    a race to get the CD out of the drive before it gets pulled back in at
+    reboot.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Thu,  3 Mar 2005 15:30:24 +0000
+
+cdrom-detect (1.04ubuntu3) hoary; urgency=low
+
+  * Fix fuzzy markers in .po files.
+  * Update Polish branding (thanks, Piotr Szotkowski).
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Mon, 14 Feb 2005 12:07:10 +0000
+
+cdrom-detect (1.04ubuntu2) hoary; urgency=low
+
+  * Move prebaseconfig script to 25 so that it comes after final-message.
+
+ -- Colin Watson <cjwatson@ubuntu.com>  Thu, 20 Jan 2005 12:06:57 +0000
+
+cdrom-detect (1.04ubuntu1) hoary; urgency=low
+
+  * Merge from Debian.
+  * Mark mirror/suite choices as untranslatable.
+  * Ubuntu-brand Latvian translation.
+
+ -- Colin Watson <cjwatson@canonical.com>  Tue, 26 Oct 2004 20:26:42 +0100
+
 cdrom-detect (1.04) unstable; urgency=low
 
   * Updated translations: 
@@ -1123,6 +1711,70 @@ cdrom-detect (0.59) unstable; urgency=lo
 
  -- Joey Hess <joeyh@debian.org>  Mon, 28 Jun 2004 14:56:58 -0400
 
+cdrom-detect (0.58ubuntu9) warty; urgency=low
+
+  * Updated translations:
+    - Catalan (ca.po) by Jordi Mallach
+    - German (de.po) by Martin Pitt
+    - Greek (el.po) by Logiotatidis George
+    - French (fr.po) by VETSEL Patrice
+
+ -- Colin Watson <cjwatson@canonical.com>  Tue, 12 Oct 2004 14:24:41 +0100
+
+cdrom-detect (0.58ubuntu8) warty; urgency=low
+
+  * Eject the CD on PowerMacs again, since archive-copier is now used by
+    default and removes the need for the CD in the second stage.
+
+ -- Colin Watson <cjwatson@canonical.com>  Tue, 14 Sep 2004 00:56:07 +0100
+
+cdrom-detect (0.58ubuntu7) warty; urgency=low
+
+  * Put up a progress bar while scanning directories.
+
+ -- Colin Watson <cjwatson@canonical.com>  Sun, 12 Sep 2004 11:32:38 +0100
+
+cdrom-detect (0.58ubuntu6) warty; urgency=low
+
+  * Unset default hdparm parameters, so it isn't used by default. You can
+    still boot with cdrom-detect/cdrom_hdparm=-c3 to get the previous
+    behaviour.
+
+ -- Colin Watson <cjwatson@canonical.com>  Thu,  9 Sep 2004 14:39:36 +0100
+
+cdrom-detect (0.58ubuntu5) warty; urgency=low
+
+  * Set CD-ROM drive parameters with hdparm.
+
+ -- Colin Watson <cjwatson@canonical.com>  Tue,  7 Sep 2004 16:27:17 +0100
+
+cdrom-detect (0.58ubuntu4) warty; urgency=low
+
+  * Ignore errors from 'find /cdrom/' (they're unlikely, but just in case).
+
+ -- Colin Watson <cjwatson@canonical.com>  Sat,  4 Sep 2004 01:02:13 +0100
+
+cdrom-detect (0.58ubuntu3) warty; urgency=low
+
+  * Run 'find /cdrom/' once the CD is mounted, to get all the directories
+    into the dentry cache. The speed increase from this is ... remarkable.
+    Seeks are *expensive*.
+
+ -- Colin Watson <cjwatson@canonical.com>  Sat,  4 Sep 2004 00:38:56 +0100
+
+cdrom-detect (0.58ubuntu2) warty; urgency=low
+
+  * Ubuntu branding
+
+ -- Tollef Fog Heen <tfheen@debian.org>  Tue, 17 Aug 2004 15:29:59 +0200
+
+cdrom-detect (0.58ubuntu1) warty; urgency=low
+
+  * Colin Watson
+    - Don't eject the CD on PowerMacs, which don't boot from CD by default.
+
+ -- Colin Watson <cjwatson@flatline.org.uk>  Tue, 17 Aug 2004 00:33:51 +0100
+
 cdrom-detect (0.58) unstable; urgency=low
 
   * Updated translations: 
diff -pruN 1.57/debian/control 1.57ubuntu9/debian/control
--- 1.57/debian/control	2013-07-13 09:00:28.000000000 +0000
+++ 1.57ubuntu9/debian/control	2015-10-27 00:11:23.000000000 +0000
@@ -1,16 +1,18 @@
 Source: cdrom-detect
 Section: debian-installer
 Priority: optional
-Maintainer: Debian Install System Team <debian-boot@lists.debian.org>
+Maintainer: Ubuntu Installer Team <ubuntu-installer@lists.ubuntu.com>
+XSBC-Original-Maintainer: Debian Install System Team <debian-boot@lists.debian.org>
 Uploaders: Christian Perrier <bubulle@debian.org>
 Build-Depends: debhelper (>= 9)
 Build-Depends-Indep: dpkg-dev (>= 1.7.0), po-debconf (>= 0.5.0)
-Vcs-Browser: http://anonscm.debian.org/gitweb/?p=d-i/cdrom-detect.git
-Vcs-Git: git://anonscm.debian.org/d-i/cdrom-detect.git
+XS-Debian-Vcs-Browser: http://anonscm.debian.org/gitweb/?p=d-i/cdrom-detect.git
+XS-Debian-Vcs-Git: git://anonscm.debian.org/d-i/cdrom-detect.git
+Vcs-Bzr: http://bazaar.launchpad.net/~ubuntu-core-dev/cdrom-detect/ubuntu
 
 Package: cdrom-detect
 Package-Type: udeb
 Architecture: all
-Depends: ${misc:Depends}, hw-detect, di-utils (>= 1.72)
+Depends: ${misc:Depends}, hw-detect, di-utils (>= 1.72), hdparm-udeb
 XB-Installer-Menu-Item: 1300
 Description: Detect CDROM devices and mount the CD
diff -pruN 1.57/debian/po/am.po 1.57ubuntu9/debian/po/am.po
--- 1.57/debian/po/am.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/am.po	2015-10-27 13:59:30.000000000 +0000
@@ -275,3 +275,18 @@ msgstr "ሲዲ ማጫወቻውን በማ
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "ሲዲ ማጫወቻውን አግኝና ጫን"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/ar.po 1.57ubuntu9/debian/po/ar.po
--- 1.57/debian/po/ar.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ar.po	2015-10-27 13:59:30.000000000 +0000
@@ -292,3 +292,22 @@ msgstr "فك وإخراج القرص ا
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "فحص وتركيب قارئ الأقراص المدمجة"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "هل تريد تعديل معطيات قارءة الأقراص المدمجة عن طريق hdparm؟"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"يستطيع برنامج التثبيت استخدام hdparm لتعديل بعض معطيات قارءة الأقراص المدمجة "
+"مما قد يحسن من سرعة قراءة الحزم من القرص المدمج بصورة ملحوظة. يمكنك تغيير "
+"المعطيات المستخدمة كما يمكنك تعطيل hdparm و ذلك عن طريق ادخال قائمة معطيات "
+"خالية."
diff -pruN 1.57/debian/po/ast.po 1.57ubuntu9/debian/po/ast.po
--- 1.57/debian/po/ast.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ast.po	2015-10-27 13:59:30.000000000 +0000
@@ -290,3 +290,22 @@ msgstr "Desmontando y espulsando'l CD-RO
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Deteutar y montar el CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "¿Axustar los parámetros de la unidá de CD-ROM con hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"El programa d'instalación pue usar hdparm p'axustar dalgunos parámetros de "
+"la unidá de CD-ROM, lo que pue acelerar significativamente la velocidá de "
+"llectura de paquetes dende'l CD. Pue camudar los parámetros que se vayan a "
+"usar. Pa desactivar hdparm, introduza una llista de parámetros erma."
diff -pruN 1.57/debian/po/be.po 1.57ubuntu9/debian/po/be.po
--- 1.57/debian/po/be.po	2015-05-21 03:00:50.000000000 +0000
+++ 1.57ubuntu9/debian/po/be.po	2015-10-27 13:59:30.000000000 +0000
@@ -301,3 +301,22 @@ msgstr "Адмацаванне і выз
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Вызначэнне і мацаванне CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Наладзіць парамэтры кружэльніка з дапамогай hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Усталёўшчык можа скарыстацца hdparm, каб наладзіць некаторыя парамэтры "
+"кружэльніка, што можа значна паскорыць чытаньне пакетаў з гэтага CD. Можаце "
+"зьмяніць парамэтры, якія будуць выкарыстоўвацца. Каб не ўжываць hdparm, "
+"падайце пусты сьпіс парамэтраў."
diff -pruN 1.57/debian/po/bg.po 1.57ubuntu9/debian/po/bg.po
--- 1.57/debian/po/bg.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/bg.po	2015-10-27 13:59:30.000000000 +0000
@@ -311,3 +311,22 @@ msgstr "Демонтиране и изв
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Разпознаване и монтиране на компактдиск"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Настройка на CD-ROM параметрите с hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Инсталаторът може да използва hdparm за настройка на някои параметри на CD-"
+"ROM устройства, което може значително да увеличи скоростта на четене на "
+"пакетите от компактдиска. Можете да промените параметрите, които ще бъдат "
+"използвани. За деактивация на hdparm въведете празен списък с параметри."
diff -pruN 1.57/debian/po/bn.po 1.57ubuntu9/debian/po/bn.po
--- 1.57/debian/po/bn.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/bn.po	2015-10-27 13:59:30.000000000 +0000
@@ -302,3 +302,22 @@ msgstr "সিডি-রম আনমা
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM সনাক্ত করে মাউন্ট করা হচ্ছে"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "hdparm দিয়ে CD-ROM ড্রাইভের প্যারামিটার টিউন করা হবে কি?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"ইনস্টলার CD-ROM ড্রাইভের কিছু প্যারামিটার টিউন করার জন্য hdparm ব্যবহার করতে পারে, "
+"এর ফলে CD থেকে প্যাকেজ পড়ার গতি উল্লেখযোগ্য হারে বৃদ্ধি পায়। এখানে কোন কোন "
+"প্যারামিটার ব্যবহৃত হবে তা আপনি পরিবর্তন করে দিতে পারেন। hdparm নিষ্ক্রিয় করতে, "
+"একটি ফাঁকা প্যারামিটার তালিকা দিন।"
diff -pruN 1.57/debian/po/bo.po 1.57ubuntu9/debian/po/bo.po
--- 1.57/debian/po/bo.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/bo.po	2015-10-27 13:59:30.000000000 +0000
@@ -270,3 +270,18 @@ msgstr "བཀར་བ་དེ་ཕ
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "འོད་སྡེར་སྒུལ་ཆས་འཚོལ་ནས་བཀར་བ"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/bs.po 1.57ubuntu9/debian/po/bs.po
--- 1.57/debian/po/bs.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/bs.po	2015-10-27 13:59:30.000000000 +0000
@@ -296,3 +296,22 @@ msgstr "Demontiranje i izbacivanje CD-RO
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detektiraj i montiraj CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Podesiti CD-ROM parametre sa hdparm-om?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Instaler može koristiti hdparm kako bi podesio parametre CD-ROM uređaja, što "
+"bi moglo značajno ubrzati čitanje paketa sa CD-a. Možete promjeniti "
+"parametre koje ćete koristiti. Kako biste onemogućili hdparm, ostavite listu "
+"parametrara praznom."
diff -pruN 1.57/debian/po/ca.po 1.57ubuntu9/debian/po/ca.po
--- 1.57/debian/po/ca.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ca.po	2015-10-27 13:59:30.000000000 +0000
@@ -293,3 +293,22 @@ msgstr "S'està desmuntant i expulsant e
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detecta i munta el CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Voleu ajustar els paràmetres de la unitat de CD-ROM amb hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"L'instal·lador pot utilitzar hdparm per a ajustar alguns paràmetres de la "
+"unitat de CD-ROM, que poden accelerar signficativament la lectura de paquets "
+"des del CD. Podeu canviar els paràmetres a utilitzar. Per a inhabilitar "
+"l'hdparm, introduïu una llista de paràmetres buida."
diff -pruN 1.57/debian/po/cs.po 1.57ubuntu9/debian/po/cs.po
--- 1.57/debian/po/cs.po	2015-05-20 03:00:50.000000000 +0000
+++ 1.57ubuntu9/debian/po/cs.po	2015-10-27 13:59:30.000000000 +0000
@@ -292,3 +292,22 @@ msgstr "Odpojuje se CD-ROM..."
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Rozpoznat a připojit CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Vyladit parametrxy CD-ROM mechaniky pomocí hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Instalátor může použít \"hdparm\" pro vyladění některých parametrů CD-ROM "
+"mechaniky, které mohou významně urychlit rychlost čtení balíků z CD. Můžete "
+"měnit parametry, které budou použity. Pro vypnutí \"hdparm\" ponechte seznam "
+"parametrů prázdný."
diff -pruN 1.57/debian/po/cy.po 1.57ubuntu9/debian/po/cy.po
--- 1.57/debian/po/cy.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/cy.po	2015-10-27 13:59:30.000000000 +0000
@@ -292,3 +292,18 @@ msgstr "Yn datglymu ac allfwrw'r CD-ROM.
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Canfod a clymu CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/da.po 1.57ubuntu9/debian/po/da.po
--- 1.57/debian/po/da.po	2015-08-17 03:00:54.000000000 +0000
+++ 1.57ubuntu9/debian/po/da.po	2015-10-27 14:00:45.000000000 +0000
@@ -314,3 +314,22 @@ msgstr "Afmonterer cd og skubber den ud
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Led efter cd-rom drev og monter cd"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Optimer CD-ROM parameter med hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Installationen kan bruge hdparm til at optimerer nogle CD-ROM drev "
+"parameter, dette kan markant øge hastigheden på læsning af pakker fra CD'en. "
+"Du kan ændre parameterne som bruges. For at deaktivere hdparm, indtast en "
+"tom parameter liste."
diff -pruN 1.57/debian/po/de.po 1.57ubuntu9/debian/po/de.po
--- 1.57/debian/po/de.po	2015-06-14 03:01:07.000000000 +0000
+++ 1.57ubuntu9/debian/po/de.po	2015-10-27 13:59:30.000000000 +0000
@@ -323,3 +323,22 @@ msgstr "Aufheben der Laufwerkseinbindung
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM erkennen und einbinden"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "CD-ROM Parameter mittels hdparm tunen?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Das Installationsprogramm kann »hdparm« verwenden, um bei einigen CD-ROM-"
+"Laufwerken die Lesegeschwindigkeit für die Pakete möglicherweise signifikant "
+"zu erhöhen. Sie können die zu verwendenden Parameter ändern. Um »hdparm« "
+"abzuschalten, lassen Sie die Parameterliste leer."
diff -pruN 1.57/debian/po/dz.po 1.57ubuntu9/debian/po/dz.po
--- 1.57/debian/po/dz.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/dz.po	2015-10-27 13:59:30.000000000 +0000
@@ -289,3 +289,18 @@ msgstr "སྦྱར་བརྩེག
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "སི་ཌི་ རོམ་སྦྱར་བརྩེགས་འམད་ནི་དང་སྐྱོན་འཛིན།"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/el.po 1.57ubuntu9/debian/po/el.po
--- 1.57/debian/po/el.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/el.po	2015-10-27 13:59:30.000000000 +0000
@@ -310,3 +310,22 @@ msgstr "Αποπροσάρτηση κα
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Ανίχνευση των μονάδων CD-ROM και προσάρτηση του CD"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Βελτιστοποίηση των παραμέτρων οδηγού CD-ROM με το hdparm;"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Η εγκατάσταση μπορεί να κάνει χρήση του  hdparm για να ρυθμίσει μερικές "
+"παραμέτρους του CD-ROM, που βοηθούν στην ταχύτητα ανάγνωση πακέτων από το "
+"CD. Μπορείτε να αλλάξετε τις παραμέτρους που θα χρησιμοποιηθούν. Για να "
+"απενεργοποιήσετε το  hdparm, βάλτε μια κενή παράμετρο."
diff -pruN 1.57/debian/po/eo.po 1.57ubuntu9/debian/po/eo.po
--- 1.57/debian/po/eo.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/eo.po	2015-10-27 13:59:30.000000000 +0000
@@ -290,3 +290,22 @@ msgstr "Malmuntado kaj elmetado de lumdi
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detekti kaj munti lumdiskon"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Ĉu vi volas agordi KD-ingajn parametrojn per 'hdparm'?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"La instalilo povas uzi 'hdparm' por agordi kelkajn parametrojn de la KD-"
+"legilo, kiuj eble signife plirapidigi la legadon de la pakaĵoj el la KD. Vi "
+"povas ŝanĝi la uzendajn parametrojn. Por malŝalti hdparm, faru malplenan "
+"parametroliston."
diff -pruN 1.57/debian/po/es.po 1.57ubuntu9/debian/po/es.po
--- 1.57/debian/po/es.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/es.po	2015-10-27 13:59:30.000000000 +0000
@@ -331,3 +331,23 @@ msgstr "Desmontando y expulsando el CD-R
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detectar y montar el CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "¿Ajustar los parámetros de la unidad de CD-ROM con hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"El programa de instalación puede usar hdparm para ajustar algunos parámetros "
+"de la unidad de CD-ROM, lo que puede acelerar significativamente la "
+"velocidad de lectura de paquetes desde el CD. Puede cambiar los parámetros "
+"que se vayan a usar. Para desactivar hdparm, introduzca una lista de "
+"parámetros vacía."
diff -pruN 1.57/debian/po/et.po 1.57ubuntu9/debian/po/et.po
--- 1.57/debian/po/et.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/et.po	2015-10-27 13:59:30.000000000 +0000
@@ -302,3 +302,22 @@ msgstr "Laserketta lahtihaakimine ja vä
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM'i tuvastamine ja haakimine"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Säti CD-ROM seadme parameetreid hdparm abil?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Paigaldaja võib hdparm-i abil CD-ROM seadme parameetreid muuta, mis võib "
+"oluliselt kiirendada pakettide plaadilt lugemist. Kasutatavaid parameertreid "
+"saad ise muuta. Hdparm-i väljalülitamiseks tuleb sisestada tühi parameetrite "
+"loetelu."
diff -pruN 1.57/debian/po/eu.po 1.57ubuntu9/debian/po/eu.po
--- 1.57/debian/po/eu.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/eu.po	2015-10-27 13:59:30.000000000 +0000
@@ -298,3 +298,21 @@ msgstr "CD-ROMa desmuntatzen eta egozten
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detektatu eta muntatu CD-ROMa"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "CD-ROM unitatearen parametroak doitu hdparm erabiliz?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Instalatzaileak hdparm erabil dezake CD-ROM unitatearen parametroak "
+"doitzeko. Honek CDaren abiadura nabarmen handitu dezake. Erabiliko diren "
+"parametroak alda ditzakezu. Zerrenda hutsik utzi hdparm ezgaitzeko."
diff -pruN 1.57/debian/po/fa.po 1.57ubuntu9/debian/po/fa.po
--- 1.57/debian/po/fa.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/fa.po	2015-10-27 13:59:30.000000000 +0000
@@ -292,3 +292,18 @@ msgstr "پیاده‌سازی و خار
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "شناخت و ماونت CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/fi.po 1.57ubuntu9/debian/po/fi.po
--- 1.57/debian/po/fi.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/fi.po	2015-10-27 13:59:30.000000000 +0000
@@ -294,3 +294,22 @@ msgstr "Irrotetaan ja poistetaan CD-levy
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Tunnista ja liitä CD-levy"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Säädetäänkö CD-aseman asetuksia hdparm-ohjelman avulla?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Asennusohjelma voi käyttää hdparm-ohjelmaa hienosäätääkseen joitain CD-"
+"asemien asetuksia, josta saattaa seurata huomattavaa suorituskyvyn nousua "
+"luettaessa paketteja CD-levyltä. Voit halutessasi muuttaa käytettäviä "
+"asetuksia. Jos et halua käyttää hdparm-ohjelmaa, älä syötä mitään asetuksia."
diff -pruN 1.57/debian/po/fr.po 1.57ubuntu9/debian/po/fr.po
--- 1.57/debian/po/fr.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/fr.po	2015-10-27 13:59:30.000000000 +0000
@@ -314,3 +314,22 @@ msgstr "Démontage du CD et éjection...
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Détecter et monter le CD"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Personnaliser les paramètres du lecteur CD avec hdparm ?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"L'installateur peut utiliser hdparm pour pour régler certains paramètres du "
+"lecteur de CD. Ceci peut  accélérer de manière notable la lecture des "
+"paquets à partir du CD. Vous pouvez modifier les paramètres à utiliser. Pour "
+"désactiver hdparm, laissez la liste de paramètres vide."
diff -pruN 1.57/debian/po/ga.po 1.57ubuntu9/debian/po/ga.po
--- 1.57/debian/po/ga.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ga.po	2015-10-27 13:59:30.000000000 +0000
@@ -291,3 +291,18 @@ msgstr "CD-ROM á dhífheistiú agus á
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Braith agus feistigh an CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/gl.po 1.57ubuntu9/debian/po/gl.po
--- 1.57/debian/po/gl.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/gl.po	2015-10-27 13:59:30.000000000 +0000
@@ -294,3 +294,22 @@ msgstr "Estase a desmontar e extraer o C
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detectar e montar o CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Axustar os parámetros da unidade de CD-ROM con hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"O instalador pode utilizar hdparm para axustar algúns parámetros da unidade "
+"de CD-ROM, o que pode acelerar notablemente a velocidade de lectura dos "
+"paquetes desde o CD. Pode cambiar os parámetros que se van usar. Para "
+"desactivar hdparm, escriba unha lista de parámetros baleira."
diff -pruN 1.57/debian/po/gu.po 1.57ubuntu9/debian/po/gu.po
--- 1.57/debian/po/gu.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/gu.po	2015-10-27 13:59:30.000000000 +0000
@@ -291,3 +291,18 @@ msgstr "સીડી-રોમને અ
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "સીડી-રોમ શોધો અને માઉન્ટ કરો"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/he.po 1.57ubuntu9/debian/po/he.po
--- 1.57/debian/po/he.po	2015-08-20 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/he.po	2015-10-27 13:59:30.000000000 +0000
@@ -300,3 +300,21 @@ msgstr "מסיר עגינה ומוציא
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "זיהוי ועגינת כונן תקליטורים"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "לכוון את כונן התקליטורים בעזרת hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"תוכנית ההתקנה יכולה להשתמש ב hdparm לכיוון פרמטרי כונן התקליטורים שלך, מה "
+"שיכול להגדיל בצורה משמעותית את מהירות קריאת החבילות מהתקליטור. תוכל לשנות את "
+"הפרמטרים בהם יעשה שימוש. לביטול הפעלת hdparm, הזן רשימת פרמטרים ריקה."
diff -pruN 1.57/debian/po/hi.po 1.57ubuntu9/debian/po/hi.po
--- 1.57/debian/po/hi.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/hi.po	2015-10-27 13:59:30.000000000 +0000
@@ -296,3 +296,22 @@ msgstr "सीडी-रॉम को 
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "सीडी-रॉम खोजें और माउंट करें"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "सीडी-रौम ड्राईव को एचडीपार्म के इस्तेमाल से बेहतरीन लय में लाऐं ?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"संस्थापक एचडीपार्म (जो कम्प्यूटर का एक प्रोग्रॉम है) को इस्तेमाल कर के सीडीरौम ड्राईव को "
+"बेहतरीन लय में ला सकता है, जिस से सीडी काफी ज़्यादा तेज़ चल सकती है। आप सीडी के लय के "
+"पैमाने को देख के बदलाव कर सकते हैं। अगर आप को एचडीपार्म नहीं इस्तेमाल करना हो, तो पैमाना "
+"सूची खाली रखें।"
diff -pruN 1.57/debian/po/hr.po 1.57ubuntu9/debian/po/hr.po
--- 1.57/debian/po/hr.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/hr.po	2015-10-27 13:59:30.000000000 +0000
@@ -291,3 +291,22 @@ msgstr "Demontiram i izbacujem CD-ROM...
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Pronađi i montiraj CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Podesiti CD-ROM parametre sa hdparm-om?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Instaler može koristiti hdparm kako bi podesio parametre CD-ROM uređaja, što "
+"bi moglo značajno ubrzati čitanje paketa sa CD-a. Možete promjeniti "
+"parametre koje ćete koristiti. Kako biste onemogućili hdparm, ostavite listu "
+"parametrara praznom."
diff -pruN 1.57/debian/po/hu.po 1.57ubuntu9/debian/po/hu.po
--- 1.57/debian/po/hu.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/hu.po	2015-10-27 13:59:30.000000000 +0000
@@ -371,3 +371,22 @@ msgstr "CD-ROM lecsatolása és kiadása
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM érzékelése és csatolása"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Hangolja a CD-ROM meghajtót a hdparm segítségével?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"A telepítő képes a hdparm segítségével bizonyos CD-ROM meghajtók "
+"hangolására, ami jelentősen gyorsíthatja a csomagok olvasását a CD-ről. Itt "
+"megváltoztathatja a használandó paramétereket. A hdparm letiltásához üres "
+"paraméterlistát adjon meg."
diff -pruN 1.57/debian/po/id.po 1.57ubuntu9/debian/po/id.po
--- 1.57/debian/po/id.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/id.po	2015-10-27 13:59:30.000000000 +0000
@@ -303,3 +303,22 @@ msgstr "Melepas dan mengeluarkan CD-ROM.
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Mencari dan mengaitkan CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Atur parameter CD-ROM dengan hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Penginstal ini dapat memanggil hdpam untuk mengatur penggerak CD-ROM yang "
+"dapat mempercepat pembacaan paket dari CD. Anda dapat mengubah parameter "
+"yang digunakan. Jika tidak ingin menggunakan hdparm, kosongkan saja ruas "
+"parameternya."
diff -pruN 1.57/debian/po/is.po 1.57ubuntu9/debian/po/is.po
--- 1.57/debian/po/is.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/is.po	2015-10-27 13:59:30.000000000 +0000
@@ -292,3 +292,22 @@ msgstr "Aftengi disk og opna geisladrif.
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Finna og tengja geisladisk"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Stilla geisladrifs-stillingar með ‚hdparm‘?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Uppsetningin getur notað ‚hdparm‘ til að stilla nokkrar "
+"geisladrifsstillingar. Þetta getur hraðað lesningu pakka frá geisladisk. Þú "
+"getur breytt stillingunum sem á að nota. Til að óvirkja ‚hdparm‘ þá þarf "
+"aðeins að slá inn tóman stillingalista."
diff -pruN 1.57/debian/po/it.po 1.57ubuntu9/debian/po/it.po
--- 1.57/debian/po/it.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/it.po	2015-10-27 13:59:30.000000000 +0000
@@ -312,3 +312,22 @@ msgstr "Smontaggio ed espulsione del CD-
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Rilevare e montare il CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Regolare i parametri dell'unità CD-ROM con hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Il sistema di installazione permette di usare hdparm per regolare alcuni "
+"parametri dell'unità CD-ROM in modo da velocizzare la lettura dei pacchetti "
+"dal CD. È possibile cambiare i parametri da usare. Per disabilitare hdparm, "
+"inserire un elenco di parametri vuoto."
diff -pruN 1.57/debian/po/ja.po 1.57ubuntu9/debian/po/ja.po
--- 1.57/debian/po/ja.po	2015-06-16 03:00:50.000000000 +0000
+++ 1.57ubuntu9/debian/po/ja.po	2015-10-27 13:59:30.000000000 +0000
@@ -301,3 +301,22 @@ msgstr "CD-ROM のアンマウントと
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM の検出とマウント"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "hdparmを使ってCD-ROMドライブのパラメータを最適化しますか？"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"インストーラーはhdparmを使用して、CD-ROMドライブのパラメーターを最適化できま"
+"す。最適化することによって、CDからのパッケージの読み込みが著しく高速化するか"
+"もしれません。使用されるパラメーターを変更できます。hdparmを無効にするには、"
+"空のパラメーターのリストを入力してください。"
diff -pruN 1.57/debian/po/ka.po 1.57ubuntu9/debian/po/ka.po
--- 1.57/debian/po/ka.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ka.po	2015-10-27 13:59:30.000000000 +0000
@@ -299,3 +299,22 @@ msgstr "CD-ROM-ის მოხსნა
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM-ის ამოცნობა და ჩამაგრება"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "გსურთ CD-ROM-ის პარამეტრების hdparm-ით ოპტიმიზება?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"CD-ROM-ის ზოგიერთი პარამეტრის ოპტიმიზებისათვის ინსტალერს hdparm-ის "
+"გამოყენება შეუძლია, რასაც CD-დან პაკეტების კითხვა საგრძნობლად შეუძლია "
+"დააჩქაროს. თქვენ შეგიძლიათ სასურველი პარამეტრების შეცვლა. hdparm-ის "
+"გამოსართავად შეიყვანეთ პარამეტრების ცარიელი სია."
diff -pruN 1.57/debian/po/kk.po 1.57ubuntu9/debian/po/kk.po
--- 1.57/debian/po/kk.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/kk.po	2015-10-27 13:59:30.000000000 +0000
@@ -289,3 +289,22 @@ msgstr "CD-ROM дискіні тірке
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM табу және тіркеу"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "CD-ROM параметрлерін hdparm бағдарламасының көмегімен баптау керек пе?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Орнатқыш hdparm бағдарламасын CD-ROM құрылғысынң кейбір параметрлерін баптау "
+"үшін қолданыла алады. Осының нәтижесінде CD-дан оқу жылдамдығы арту мүмкін. "
+"Осы баптауларды қолмен де көрсетуге болады. Hdparm бағдарламасын өшіру үшін "
+"параметрлер жолын бос қалдырыңыз."
diff -pruN 1.57/debian/po/km.po 1.57ubuntu9/debian/po/km.po
--- 1.57/debian/po/km.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/km.po	2015-10-27 13:59:30.000000000 +0000
@@ -277,3 +277,21 @@ msgstr "កំពុង​អាន់
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "រក និង ម៉ោន​ស៊ីឌីរ៉ូម"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "ដាក់​ប៉ារ៉ាម៉ែត្រ​ដ្រាយ ស៊ីឌីរ៉ូមឲ្យ​ត្រូវគ្នា​ជា​មួយ hdparm ឬ ?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"កម្មវិធី​ដំឡើង អាច​ប្រើ hdparm ដើម្បី​តម្រូវ​ប៉ារ៉ាម៉ែត្រ​ដ្រាយស៊ីឌីរ៉ូម មួយ​ចំនួន ដែល​នឹង​បង្កើនល្បឿន​ក្នុង​ការ​"
+"អាន​កញ្ចប់​ពី​ស៊ីឌី ។ អ្នក​អាច​ផ្លាស់ប្ដូរ​ប៉ារ៉ាម៉ែត្រ​បាន ដើម្បី​ប្រើ ។ ដើម្បី​បិទ hdparm គឺ​ត្រូវ​បញ្ចូល​នូវ​បញ្ជី​"
+"ប៉ារ៉ាម៉ែត្រ​ទទេ​មួយ ។"
diff -pruN 1.57/debian/po/kn.po 1.57ubuntu9/debian/po/kn.po
--- 1.57/debian/po/kn.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/kn.po	2015-10-27 13:59:30.000000000 +0000
@@ -288,3 +288,18 @@ msgstr "ಸಿ ಡಿ ರೋಮ್ ಅ
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "ಸಿಡಿ-ರಾಮ್ ಪತ್ತೆ ಹಚ್ಚಿ ಹಾಗು ಮೇಲೆರಿಸಿ"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/ko.po 1.57ubuntu9/debian/po/ko.po
--- 1.57/debian/po/ko.po	2015-05-18 03:00:50.000000000 +0000
+++ 1.57ubuntu9/debian/po/ko.po	2015-10-27 13:59:30.000000000 +0000
@@ -299,3 +299,22 @@ msgstr "CD-ROM을 마운트 해제하고
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM 찾기 및 마운트"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "hdparm을 사용하여 시디롬 드라이브의 파라미터들을 조절할까요?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"이 설치 프로그램은 시디롬 드라이브의 파라미터 조절을 위해 hdparm을 사용할 수 "
+"있습니다. 이를 통해, 시디로 부터 꾸러미를 읽어오는 속도를 상당히 개선할 수 있"
+"습니다. 사용할 파라미터들을 여러분이 직접 변경할 수 있습니다. hdparm을 사용하"
+"지 않으려면, 비어있는 파라미터 리스트를 입력하세요."
diff -pruN 1.57/debian/po/ku.po 1.57ubuntu9/debian/po/ku.po
--- 1.57/debian/po/ku.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ku.po	2015-10-27 13:59:30.000000000 +0000
@@ -290,3 +290,22 @@ msgstr "CD-ROM tê unmountkirin û avêt
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM bibîne û mount bike"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Bila parametreyên ajogera CD-ROM' ê bi hdparm ê were mîheng kirin?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Bernameya sazkirinê, ji bo lezgînkirina xwendina ji pakêtan a ji CD'yê "
+"mîhengkirina hin parametreyên ajokarê CD-ROM'ê, dikare hdparm'ê bi kar bîne. "
+"Tu dikarî parametreyên ku dê bên bikaranîn biguharînî. Ji bo tu hdparm'ê "
+"neçalak bikî, lîsteyeke vala ya parametreyê binivîse."
diff -pruN 1.57/debian/po/lo.po 1.57ubuntu9/debian/po/lo.po
--- 1.57/debian/po/lo.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/lo.po	2015-10-27 13:59:30.000000000 +0000
@@ -275,3 +275,18 @@ msgstr "ກຳລັງເລີກເ
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "ກວດຫາ ແລະ ເມົາຊີດີ"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/lt.po 1.57ubuntu9/debian/po/lt.po
--- 1.57/debian/po/lt.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/lt.po	2015-10-27 13:59:30.000000000 +0000
@@ -297,3 +297,22 @@ msgstr "CD-ROM laikmenos atjungimas ir i
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM įrenginio aptikimas ir CD prijungimas"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Ar suderinti CD-ROM įrenginio parametrus su „hdparm“?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Diegiklis gali naudoti hdparm CD-ROM irenginio darbo parametrų nustatymui, "
+"kas gali smarkiai pagreitinti paketu skaitymą iš kompaktinio disko. Galite "
+"pasirinkti parametrų nustatymus. Norėdami išjungti hdparm ištrinkite "
+"parametrų eilutę."
diff -pruN 1.57/debian/po/lv.po 1.57ubuntu9/debian/po/lv.po
--- 1.57/debian/po/lv.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/lv.po	2015-10-27 13:59:30.000000000 +0000
@@ -297,3 +297,22 @@ msgstr "Atmontē un izgrūž CD-ROM..."
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Noteikt un piemontēt CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Pielāgot CD-ROM dziņa parametrus, izmantojot hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Instalators var lietot hdparm, lai pielāgotu CD-ROM dziņa parametrus. Tas "
+"varētu uzlabot ātrumu, ar kādu tiks nolasītas pakotnes no CD. Jūs varat "
+"mainīt parametrus, kuri tiks lietoti. Lai atslēgtu hdparm lietošanu, "
+"ievadiet tukšu parametru rindu."
diff -pruN 1.57/debian/po/mk.po 1.57ubuntu9/debian/po/mk.po
--- 1.57/debian/po/mk.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/mk.po	2015-10-27 13:59:30.000000000 +0000
@@ -294,3 +294,22 @@ msgstr "Демонтирање и вад
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Детектирање и монтирање CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Да ги поставам ги параметрите на CD-ROM драјвот со hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Инсталерот може да користи hdparm за да постави некои параметри на CD-ROM "
+"драјвот кои можат значајно да го забрзаат читањето на пакетите од CD-то. "
+"Можете да ги промените параметрите кои ќе се користат. За да го оневозможите "
+"hdparm, не внесувајте ништо во листата со параметри."
diff -pruN 1.57/debian/po/ml.po 1.57ubuntu9/debian/po/ml.po
--- 1.57/debian/po/ml.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ml.po	2015-10-27 13:59:30.000000000 +0000
@@ -296,3 +296,18 @@ msgstr "സിഡി-റോം അണ്
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "സിഡി-റോം തിരിച്ചറിഞ്ഞു് മൌണ്ട് ചെയ്യുക"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/mr.po 1.57ubuntu9/debian/po/mr.po
--- 1.57/debian/po/mr.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/mr.po	2015-10-27 13:59:30.000000000 +0000
@@ -286,3 +286,24 @@ msgstr "सीडी-रॉम अना
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "सीडी-रॉम शोधा आणि आरोहित करा."
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+"एचडीपीएआरएम(hdparm) ने फक्त वाचनीय स्मृति सघन चकती(सिडी-रॉम) चालकाचे चलित मूल्ये "
+"मिळवायचे का?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"प्रतिष्ठापक फक्त वाचनीय स्मृति सघन चकती(सिडी-रॉम) चालकाचे काही चलित मूल्ये "
+"मिळविण्यासाठी एचडीपीएआरएम(hdparm) वापरु शकतो, ज्याने सघन चकती वरील पुडके वाचण्याचा "
+"वेग सार्थपणे वाढु शकतो. तुम्ही वापरायची चलित मूल्ये बदलु शकता. एचडीपीएआरएम(hdparm) "
+"निक्रिय करण्यासाठी, रिकामी चलित मूल्य यादीची निविष्टि करा."
diff -pruN 1.57/debian/po/nb.po 1.57ubuntu9/debian/po/nb.po
--- 1.57/debian/po/nb.po	2015-05-21 03:00:50.000000000 +0000
+++ 1.57ubuntu9/debian/po/nb.po	2015-10-27 13:59:30.000000000 +0000
@@ -306,3 +306,22 @@ msgstr "Avmonterer og løser ut CD-en ..
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Finn og monter CD-en"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Finstille CD-ROM-parametere med hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Installeringsprogrammet kan bruke hdparm til og finpusse på instillingene "
+"til CD-ROM'en som kan hjelpe på farten under lesing av pakker fra CD'en. Du "
+"kan endre hvilke instillinger som skal bli brukt. For å deaktivere hdparm, "
+"la parameterlisten være tom."
diff -pruN 1.57/debian/po/ne.po 1.57ubuntu9/debian/po/ne.po
--- 1.57/debian/po/ne.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ne.po	2015-10-27 13:59:30.000000000 +0000
@@ -290,3 +290,18 @@ msgstr "सी डी-रोम अन
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "सी डी-रोम पत्ता लगाउनुहोस् र माउण्ट गर्नुहोस्"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/nl.po 1.57ubuntu9/debian/po/nl.po
--- 1.57/debian/po/nl.po	2015-07-13 03:00:53.000000000 +0000
+++ 1.57ubuntu9/debian/po/nl.po	2015-10-27 13:59:30.000000000 +0000
@@ -313,3 +313,22 @@ msgstr "CD wordt losgekoppeld en uitgewo
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Automatische herkenning en aankoppeling van de CD"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Parameters van het CD-ROM-station instellen met hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Het installatieprogramma kan hdparm gebruiken om enkele parameters voor het "
+"CD-ROM-station in te stellen die het lezen van pakketten van de CD "
+"aanzienlijk kunnen versnellen. U kunt de parameters die gebruikt worden "
+"wijzigen. Om hdparm uit te schakelen, laat u de parameterlijst leeg."
diff -pruN 1.57/debian/po/nn.po 1.57ubuntu9/debian/po/nn.po
--- 1.57/debian/po/nn.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/nn.po	2015-10-27 13:59:30.000000000 +0000
@@ -295,3 +295,22 @@ msgstr "Avmonterer og løyser ut CD …
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Finn og monter CDROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Vil du finstille grenseverdiane for CD-ROM-stasjonen med hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Installeringsprogrammet kan nytte hdparm til å finstille grenseverdiar på CD-"
+"ROM-stasjonen. Dette kan auke farten under lesing av pakkar frå CD'en. Du "
+"kan endre på desse verdiane her. Om du ikkje ønskjer å nytta hdparm let du "
+"parameterlista stå tom."
diff -pruN 1.57/debian/po/pa.po 1.57ubuntu9/debian/po/pa.po
--- 1.57/debian/po/pa.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/pa.po	2015-10-27 13:59:30.000000000 +0000
@@ -290,3 +290,18 @@ msgstr "CD-ROM ਅਣ-ਮਾਊਂਟ 
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM ਖੋਜ ਅਤੇ ਮਾਊਂਟ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/pl.po 1.57ubuntu9/debian/po/pl.po
--- 1.57/debian/po/pl.po	2015-08-14 03:00:59.000000000 +0000
+++ 1.57ubuntu9/debian/po/pl.po	2015-10-27 13:59:30.000000000 +0000
@@ -315,3 +315,22 @@ msgstr "Odmontowywanie i wysuwanie CD-RO
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Wykryj urządzenia CD-ROM i zamontuj płytę CD"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Dostroić parametry napędu CD-ROM używając hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Instalator może użyć hdparma aby dostroić parametry napędu CD-ROM, co może "
+"znaczaco podnieść prędkość odczytywania pakietów z płyty CD. Możesz zmienić "
+"parametry, które będą użyte. Aby nie używać hdparm, podaj pustą listę "
+"parametrów."
diff -pruN 1.57/debian/po/pt_BR.po 1.57ubuntu9/debian/po/pt_BR.po
--- 1.57/debian/po/pt_BR.po	2015-05-17 03:00:53.000000000 +0000
+++ 1.57ubuntu9/debian/po/pt_BR.po	2015-10-27 13:59:30.000000000 +0000
@@ -303,3 +303,22 @@ msgstr "Desmontando e ejetando o CD-ROM.
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detectar e montar o CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Ajustar parâmetros do CD-ROM com hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"O instalador pode usar o hdparm para ajustar alguns parâmetros do CD-ROM, os "
+"quais podem melhorar o desempenho do dispositivo ao ler pacotes do CD. Você "
+"pode alterar os parâmetros que serão usados. Para desabilitar o hdparm, "
+"deixe a lista em branco."
diff -pruN 1.57/debian/po/pt.po 1.57ubuntu9/debian/po/pt.po
--- 1.57/debian/po/pt.po	2015-05-17 03:00:53.000000000 +0000
+++ 1.57ubuntu9/debian/po/pt.po	2015-10-27 13:59:30.000000000 +0000
@@ -303,3 +303,22 @@ msgstr "Desmontar e ejectar o CD-ROM..."
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detectar e montar o CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Configurar parâmetros do CD-ROM com o hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"O instalador pode utilizar o hdparm para configurar alguns parâmetros do CD-"
+"ROM, p que pode melhorar a leitura dos pacotes do CD significativamente. "
+"Pode alterar os parâmetros a serem usados. Para desactivar o hdparm "
+"introduza uma lista de parâmetros vazia."
diff -pruN 1.57/debian/po/ro.po 1.57ubuntu9/debian/po/ro.po
--- 1.57/debian/po/ro.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ro.po	2015-10-27 13:59:30.000000000 +0000
@@ -309,3 +309,22 @@ msgstr "Se demontează și se scoate CD-
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Detectează și montează CD-ul"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Doriți să reglați parametrii CD-ROM-ului cu hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Acest instaler poate folosi hdparm să regleze unii parametri ai CD-ROM-ului, "
+"ceea ce poate să mărească in mod semnificativ viteza de citire a pachetelor "
+"de pe CD. Puteți să schimbați parametri folosiți. Pentru a scoate din uz "
+"hdparm, introduceți o listă fără parametri."
diff -pruN 1.57/debian/po/ru.po 1.57ubuntu9/debian/po/ru.po
--- 1.57/debian/po/ru.po	2015-06-21 03:00:45.000000000 +0000
+++ 1.57ubuntu9/debian/po/ru.po	2015-10-27 13:59:30.000000000 +0000
@@ -305,3 +305,22 @@ msgstr "Размонтирование 
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Поиск и монтирование CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Настроить параметры CD-ROM с помощью программы hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Установщик может использовать программу hdparm для настройки некоторых "
+"параметров привода CD-ROM. Настройка может значительно увеличить скорость "
+"чтения установочных пакетов с CD. Вы также можете сами изменить используемые "
+"параметры. Для отключения hdparm введите пустую строку параметров."
diff -pruN 1.57/debian/po/se.po 1.57ubuntu9/debian/po/se.po
--- 1.57/debian/po/se.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/se.po	2015-10-27 13:59:30.000000000 +0000
@@ -267,3 +267,18 @@ msgstr "Galgamin ja bálkesteamen CD …
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Áicca ja čana CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/si.po 1.57ubuntu9/debian/po/si.po
--- 1.57/debian/po/si.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/si.po	2015-10-27 13:59:30.000000000 +0000
@@ -283,3 +283,18 @@ msgstr "CD-ROM අස්ථාපනය
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM හඳුනාගෙන රඳවන්න"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/sk.po 1.57ubuntu9/debian/po/sk.po
--- 1.57/debian/po/sk.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/sk.po	2015-10-27 13:59:30.000000000 +0000
@@ -301,3 +301,21 @@ msgstr "CD-ROM sa odpája a vysúva..."
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Rozpoznanie a pripojenie CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Vyladiť parametre CD-ROM mechaniky programom hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Inštalátor môže použiť program hdparm aby vyladil parametre CD-ROM "
+"mechaniky. To môže zrýchliť načítavanie balíkov z CD. Teraz môžete zmeniť "
+"použité parametre. Pokiaľ nič nezadáte, hdparm sa nepoužije."
diff -pruN 1.57/debian/po/sl.po 1.57ubuntu9/debian/po/sl.po
--- 1.57/debian/po/sl.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/sl.po	2015-10-27 13:59:30.000000000 +0000
@@ -307,3 +307,22 @@ msgstr "Odklapljanje in odstranitev CD-R
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Zaznaj in priklopi CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Ali želite optimizirati nastavitve CD-ROM-a s hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Namestilnik lahko uporabi hdparm za optimizacijo nastavitev CD-ROM-a, kar "
+"lahko precej pospeši branje paketov z njega. Nastavitve je mogoče ročno "
+"spremeniti. V kolikor programa hdparm ne želite uporabljati, ne vpišite "
+"parametrov."
diff -pruN 1.57/debian/po/sq.po 1.57ubuntu9/debian/po/sq.po
--- 1.57/debian/po/sq.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/sq.po	2015-10-27 13:59:30.000000000 +0000
@@ -288,3 +288,22 @@ msgstr "Duke çmontuar dhe nxjerrë CD-R
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Gjej dhe monto CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Të rregulloj parametrat e draivit CD-ROM me hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Instaluesi mund të përdorë hdparm për të rregulluar disa nga parametrat e CD-"
+"ROM, gjë që mund të shpejtojë në mënyrë domethënëse leximin e paketave nga "
+"disku. Ju mund t'i ndryshoni parametrat që do të përdoren. Për të "
+"çaktivizuar hdparm, futni një listë të zbrazët të parametrave."
diff -pruN 1.57/debian/po/sr.po 1.57ubuntu9/debian/po/sr.po
--- 1.57/debian/po/sr.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/sr.po	2015-10-27 13:59:30.000000000 +0000
@@ -293,3 +293,22 @@ msgstr "Демонтирање и изб
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Пронађи и монтирај CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Подесити CD-ROM параметре са hdparm-ом?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Инсталер може користити hdparm како би подесио параметре CD-ROM уређаја, што "
+"би могло значајно убрзати читање пакета са CD-а. Можете променити параметре "
+"које ћете користити. Како бисте онемогућили hdparm, оставите листу "
+"параметрара празном."
diff -pruN 1.57/debian/po/sv.po 1.57ubuntu9/debian/po/sv.po
--- 1.57/debian/po/sv.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/sv.po	2015-10-27 13:59:30.000000000 +0000
@@ -299,3 +299,22 @@ msgstr "Avmonterar och matar ut cd-skiva
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Identifiera och montera cd-rom"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Finställ cd-rom-enhetens parametrar med hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Installationen kan använda hdparm för att finställa några av cd-rom-enhetens "
+"parametrar, vilket drastiskt kan öka hastigheten på läsning av paket från "
+"cdn. Du kan ändra parametrarna som ska användas. För att avaktivera hdparm, "
+"skriv in en tom parameter-lista."
diff -pruN 1.57/debian/po/ta.po 1.57ubuntu9/debian/po/ta.po
--- 1.57/debian/po/ta.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ta.po	2015-10-27 13:59:30.000000000 +0000
@@ -293,3 +293,21 @@ msgstr "குறுந்தட்ட
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "குறுந்தட்டை கண்டறிந்து ஏற்றவும்"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "குறுந்தட்டு இயக்கியை ஹெச்டிபார்ம் (hdparm) அளபுருக்களால் அமைக்கலாமா?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"நிறுவி ஹெச்டிபார்ம் (hdparm) ஆல் குறுந்தட்டு இயக்கி அளபுருக்களை அமைக்க இயலும். இது "
+"குறுந் தட்டிலிருந்து பொதிகளை விரைவில் படிக்க உதவும். நீங்கள் இயக்கி அளபுருக்களை மாற்றி "
+"அமைக்க முடியும். ஹெச்டிபார்ம் ஐ செயல் நீக்க, காலி அளபுரு பட்டியலிலை உள்ளிடுக."
diff -pruN 1.57/debian/po/templates.pot 1.57ubuntu9/debian/po/templates.pot
--- 1.57/debian/po/templates.pot	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/templates.pot	2015-10-27 13:59:30.000000000 +0000
@@ -252,3 +252,18 @@ msgstr ""
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/te.po 1.57ubuntu9/debian/po/te.po
--- 1.57/debian/po/te.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/te.po	2015-10-27 13:59:30.000000000 +0000
@@ -283,3 +283,18 @@ msgstr "CD-ROM అనుసంధాన
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "సీడీ-రామ్ ని కనుగొని మౌంట్ చెయ్యి"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/tg.po 1.57ubuntu9/debian/po/tg.po
--- 1.57/debian/po/tg.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/tg.po	2015-10-27 13:59:30.000000000 +0000
@@ -290,3 +290,18 @@ msgstr "Ҷудокунӣ ва барор
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Муайян ва васл кардани CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr ""
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/th.po 1.57ubuntu9/debian/po/th.po
--- 1.57/debian/po/th.po	2015-10-02 03:00:52.000000000 +0000
+++ 1.57ubuntu9/debian/po/th.po	2015-10-27 13:59:30.000000000 +0000
@@ -289,3 +289,21 @@ msgstr "กำลังเลิกเ
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "ตรวจหาและเมานท์ซีดีรอม"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "ปรับแต่งค่าของเครื่องเล่นซีดีรอมด้วยโปรแกรม hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"โปรแกรมติดตั้งสามารถใช้โปรแกรม hdparm ปรับแต่งค่าของเครื่องเล่นซีดีรอม "
+"ซึ่งอาจจะทำให้สามารถอ่นข้อมูลจากซีดีได้เร็วขึ้น ท่านสามารถเปลี่ยนค่าที่จะใช้ได้. "
+"ถ้าไม่ต้องการใช้โปรแกรม hdparm กรุณาใส่ค่าเปล่า"
diff -pruN 1.57/debian/po/tl.po 1.57ubuntu9/debian/po/tl.po
--- 1.57/debian/po/tl.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/tl.po	2015-10-27 13:59:30.000000000 +0000
@@ -297,3 +297,18 @@ msgstr "Ina-unmount at iluluwa ang CD-RO
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Hanapin at mag-mount ng CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Nais mo bang isaayos ang parameters ng CD-ROM gamit ang hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
diff -pruN 1.57/debian/po/tr.po 1.57ubuntu9/debian/po/tr.po
--- 1.57/debian/po/tr.po	2015-07-01 03:00:54.000000000 +0000
+++ 1.57ubuntu9/debian/po/tr.po	2015-10-27 13:59:30.000000000 +0000
@@ -306,3 +306,22 @@ msgstr "CD ayrılıyor ve çıkarılıyo
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM'u algıla ve bağla"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "CD-ROM sürücü parametreleri hdparm ile ayarlansın mı?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Kurulum programı, paketleri CD'den okumayı önemli ölçüde hızlandırabilecek "
+"olan bazı CD-ROM sürücü parametrelerini ayarlamak için, hdparm'ı "
+"kullanabilir. Kullanılacak olan parametreleri değiştirebilirsiniz. hdparm'ı "
+"devre dışı bırakmak için, boş bir parametre listesi girin."
diff -pruN 1.57/debian/po/ug.po 1.57ubuntu9/debian/po/ug.po
--- 1.57/debian/po/ug.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/ug.po	2015-10-27 13:59:30.000000000 +0000
@@ -291,3 +291,22 @@ msgstr "CD-ROM نى ئېگەرسىزلە
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "CD-ROM نى تەكشۈرۈپ ئېگەرلە"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "hdparm قورالىنى ئىشلىتىپ CD-ROM قوزغاتقۇچ پارامېتىرىنى تەڭشەمسىز؟"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"ئورنىتىش پروگراممىسى hdparm نى ئىشلىتىپ CD-ROM قوزغاتقۇچنىڭ بەزى "
+"پارامېتىرلىرىنى تەڭشىيەلەيدۇ، بۇنداق بولغاندا CD-ROM نىڭ ئوقۇش سۈرئىتى "
+"كۆرۈنەرلىك ئۆسىدۇ. ئىشلىتىۋاتقان پارامېتىرنى ئۆزگەرتسىڭىز بولىدۇ. "
+"پارامېتىرلار بوش قالدۇرۇلسا hdparm ئىشلىتىش چەكلىنىدۇ."
diff -pruN 1.57/debian/po/uk.po 1.57ubuntu9/debian/po/uk.po
--- 1.57/debian/po/uk.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/uk.po	2015-10-27 13:59:30.000000000 +0000
@@ -297,3 +297,21 @@ msgstr "Розмонтування та
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Знайти та змонтувати CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Налаштувати параметри CD-ROM за допомогою hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Програма встановлення може налаштувати CD-ROM за допомою hdparm. Це може "
+"значно прискорити зчитування пакунків з  CD. Ви може змінювати налаштування. "
+"Для відключення hdparm, введіть порожній перелік параметрів."
diff -pruN 1.57/debian/po/vi.po 1.57ubuntu9/debian/po/vi.po
--- 1.57/debian/po/vi.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/vi.po	2015-10-27 13:59:30.000000000 +0000
@@ -295,3 +295,22 @@ msgstr "Đang tháo lắp và đẩy ra
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "Dò tìm và lắp đĩa CD-ROM"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "Chỉnh thông số của ổ đĩa CD-ROM với hdparm?"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"Chương trình cài đặt có thể dùng hdparm để chỉnh một vài thông số của ổ đĩa "
+"CD-ROM, mà nó có thể tăng tốc việc đọc các gói từ CCD một cách đáng kể. Bạn "
+"có thể thay đổi các thông số được sử dụng. Để vô hiệu hóa hdparm, hãy nhập "
+"vào một danh sách thông số rỗng."
diff -pruN 1.57/debian/po/zh_CN.po 1.57ubuntu9/debian/po/zh_CN.po
--- 1.57/debian/po/zh_CN.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/zh_CN.po	2015-10-27 13:59:30.000000000 +0000
@@ -295,3 +295,20 @@ msgstr "卸载并弹出 CD-ROM..."
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "探测并挂载光盘"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "用 hdparm 工具调试光驱的参数？"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"安装程序可以使用 hdparm 来调整 CD-ROM 的一些参数，这样可能会显著的提高光驱的"
+"读取速度。您可以更改使用的参数。输入空白的参数列表以禁用 hdparm。"
diff -pruN 1.57/debian/po/zh_TW.po 1.57ubuntu9/debian/po/zh_TW.po
--- 1.57/debian/po/zh_TW.po	2015-05-15 03:00:56.000000000 +0000
+++ 1.57ubuntu9/debian/po/zh_TW.po	2015-10-27 13:59:30.000000000 +0000
@@ -295,3 +295,21 @@ msgstr "正在卸載並退出光碟片
 #: ../cdrom-detect.templates:20001
 msgid "Detect and mount CD-ROM"
 msgstr "偵測並掛載光碟片"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid "Tune CD-ROM drive parameters with hdparm?"
+msgstr "是否根據 hdparm 程式以微調 CD-ROM 驅動器的參數設定？"
+
+#. Type: string
+#. Description
+#: ../cdrom-detect.templates:122
+msgid ""
+"The installer can use hdparm to tune some CD-ROM drive parameters, which may "
+"significantly speed up reading packages from the CD. You can change the "
+"parameters to be used. To disable hdparm, enter an empty parameter list."
+msgstr ""
+"本安裝程式可以利用 hdparm 程式以進行微調 CD-ROM 驅動器的參數設定，由此可以加"
+"速讀取 CD 中的套件。 您可以自行設定以下參數。 如果您不要執行 hdparm 程式，請"
+"在以下參數列表中留白。"
diff -pruN 1.57/finish-install 1.57ubuntu9/finish-install
--- 1.57/finish-install	2011-01-19 04:31:06.000000000 +0000
+++ 1.57ubuntu9/finish-install	2015-10-27 00:11:23.000000000 +0000
@@ -23,3 +23,71 @@ if [ -n "$CDDEV" ]; then
 else
 	log "Not ejecting CD, as nothing is mounted."
 fi
+
+ARCH="`udpkg --print-architecture`"
+if [ "$ARCH" = i386 ]; then
+	# Set CD-ROM drive parameters for post-reboot.
+
+	db_get cdrom-detect/cdrom_device
+	device="$RET"
+
+	db_get cdrom-detect/cdrom_hdparm
+	params="$RET"
+
+	if [ "$device" ] && [ "$params" ]; then
+		mappeddevice="`mapdevfs "$device"`"
+		cat >>/target/etc/hdparm.conf <<EOF
+
+# Added by debian-installer
+
+$mappeddevice {
+EOF
+		set -- $params
+		while [ "$1" ]; do
+			name="$1"
+			shift
+			case "$name" in
+			    -??*)
+				value="${name#-?}"
+				name="`printf '%s' "$name" | sed 's/^\(-.\).*/\1/'`"
+				;;
+			    -?*)
+				value="$1"
+				shift
+				;;
+			    *)
+				continue
+				;;
+			esac
+			boolvalue=no
+			case "$name" in
+			    -a) mappedname=read_ahead_sect ;;
+			    -A) mappedname=lookahead;		boolvalue=yes ;;
+			    -b) mappedname=bus;			boolvalue=yes ;;
+			    -B) mappedname=apm ;;
+			    -c) mappedname=io32_support ;;
+			    -d) mappedname=dma;			boolvalue=yes ;;
+			    -D) mappedname=defect_mana;		boolvalue=yes ;;
+			    -E) mappedname=cd_speed ;;
+			    -m) mappedname=mult_sect_io ;;
+			    -P) mappedname=prefetch_sect ;;
+			    -S) mappedname=spindown_time ;;
+			    -u) mappedname=interrupt_unmask;	boolvalue=yes ;;
+			    -X) mappedname=transfer_mode ;;
+			    *)  continue ;;
+			esac
+			if [ "$boolvalue" = yes ]; then
+				case "$value" in
+				    0) mappedvalue=off ;;
+				    1) mappedvalue=on ;;
+				    *) continue ;;
+				esac
+			else
+				mappedvalue="$value"
+			fi
+			printf '\t%s = %s\n' "$mappedname" "$mappedvalue" \
+				>>/target/etc/hdparm.conf
+		done
+		echo '}' >>/target/etc/hdparm.conf
+	fi
+fi
